==> jc-1.4.0.tar.gz: javax/swing/JInternalFrame__24JDesktopIcon.h <==
// public class javax.swing.JInternalFrame$JDesktopIcon

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class 281fbf6e2c3ca8b3 javax_swing_JInternalFrame__24JDesktopIcon

// header file dependencies
// @dep_header javax_swing_JComponent

#include "javax/swing/JComponent.h"

#ifndef _JC_javax_swing_JInternalFrame__24JDesktopIcon_H_
#define _JC_javax_swing_JInternalFrame__24JDesktopIcon_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleContext$object;
struct _jc_javax_swing_JDesktopPane$object;
struct _jc_javax_swing_JInternalFrame$object;
struct _jc_javax_swing_plaf_DesktopIconUI$object;

// Typedefs
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_refs	_jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_refs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_nonrefs	_jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_nonrefs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$refs	_jc_javax_swing_JInternalFrame__24JDesktopIcon$refs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$nonrefs	_jc_javax_swing_JInternalFrame__24JDesktopIcon$nonrefs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object	_jc_javax_swing_JInternalFrame__24JDesktopIcon$object;

typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$fields_struct	_jc_javax_swing_JInternalFrame__24JDesktopIcon$fields_struct;
typedef const struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$vmethods	_jc_javax_swing_JInternalFrame__24JDesktopIcon$vmethods;
typedef const struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$vtable	_jc_javax_swing_JInternalFrame__24JDesktopIcon$vtable;
typedef const struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$vtype	_jc_javax_swing_JInternalFrame__24JDesktopIcon$vtype;

// Class fields structure
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24swing__24JDesktopPane;
};
extern _jc_javax_swing_JInternalFrame__24JDesktopIcon$fields_struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$class_fields;

// Constructors
extern void _jc_javax_swing_JInternalFrame__24JDesktopIcon$method$_init$cd9aac833f4912ad(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *, struct _jc_javax_swing_JInternalFrame$object *);

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);
extern struct _jc_javax_swing_JDesktopPane$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon$method$getDesktopPane$eb64c9f6f844d088(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);
extern struct _jc_javax_swing_JInternalFrame$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon$method$getInternalFrame$41cafd82a495e64a(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);
extern struct _jc_javax_swing_plaf_DesktopIconUI$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon$method$getUI$503dd991769744f7(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);
extern struct _jc_java_lang_String$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon$method$getUIClassID$ec5a776389969db1(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);
extern void _jc_javax_swing_JInternalFrame__24JDesktopIcon$method$setInternalFrame$5fa8b4e3c72553a7(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *, struct _jc_javax_swing_JInternalFrame$object *);
extern void _jc_javax_swing_JInternalFrame__24JDesktopIcon$method$setUI$a125c5fa92a72967(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *, struct _jc_javax_swing_plaf_DesktopIconUI$object *);
extern void _jc_javax_swing_JInternalFrame__24JDesktopIcon$method$updateUI$46bebc7909e18fa1(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$getDesktopPane$eb64c9f6f844d088;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$getInternalFrame$41cafd82a495e64a;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$getUI$503dd991769744f7;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$getUIClassID$ec5a776389969db1;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$setInternalFrame$5fa8b4e3c72553a7;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$setUI$a125c5fa92a72967;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$updateUI$46bebc7909e18fa1;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$vmethods {
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);
	struct _jc_javax_swing_JDesktopPane$object	*(*getDesktopPane$eb64c9f6f844d088)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);
	struct _jc_javax_swing_JInternalFrame$object	*(*getInternalFrame$41cafd82a495e64a)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);
	struct _jc_javax_swing_plaf_DesktopIconUI$object	*(*getUI$503dd991769744f7)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);
	struct _jc_java_lang_String$object	*(*getUIClassID$ec5a776389969db1)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);
	void	(*setInternalFrame$5fa8b4e3c72553a7)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *, struct _jc_javax_swing_JInternalFrame$object *);
	void	(*setUI$a125c5fa92a72967)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *, struct _jc_javax_swing_plaf_DesktopIconUI$object *);
	void	(*updateUI$46bebc7909e18fa1)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *);
};

// Vtable
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon$vmethods	javax_swing_JInternalFrame__24JDesktopIcon;
};

// Vtype
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$vtype {
	_jc_type			type;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_refs {
	struct _jc_javax_swing_JInternalFrame$object	*frame;
};

// Reference instance fields (object)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$refs {
    _jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_refs	javax_swing_JInternalFrame__24JDesktopIcon;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_nonrefs	javax_swing_JInternalFrame__24JDesktopIcon;
};

// Object instance structure
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object {
	_jc_javax_swing_JInternalFrame__24JDesktopIcon$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon$vtype	*vtype;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JInternalFrame__24JDesktopIcon$vtype _jc_javax_swing_JInternalFrame__24JDesktopIcon$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JInternalFrame__24JDesktopIcon, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JInternalFrame__24JDesktopIcon$class_object;

#endif	/* _JC_javax_swing_JInternalFrame__24JDesktopIcon_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JInternalFrame__24JDesktopIcon.h <==
// public class javax.swing.JInternalFrame$JDesktopIcon

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class 281fbf6e2c3ca8b3 javax_swing_JInternalFrame__24JDesktopIcon

// header file dependencies
// @dep_header javax_swing_JComponent

#include "javax/swing/JComponent.h"

#ifndef _JC_javax_swing_JInternalFrame__24JDesktopIcon_H_
#define _JC_javax_swing_JInternalFrame__24JDesktopIcon_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_accessibility_AccessibleContext$object;
struct _jc_javax_swing_JDesktopPane$object;
struct _jc_javax_swing_JInternalFrame$object;
struct _jc_javax_swing_plaf_DesktopIconUI$object;

// Typedefs
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_refs	_jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_refs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_nonrefs	_jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_nonrefs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$refs	_jc_javax_swing_JInternalFrame__24JDesktopIcon$refs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$nonrefs	_jc_javax_swing_JInternalFrame__24JDesktopIcon$nonrefs;
typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object	_jc_javax_swing_JInternalFrame__24JDesktopIcon$object;

typedef struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$fields_struct	_jc_javax_swing_JInternalFrame__24JDesktopIcon$fields_struct;
typedef const struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$vmethods	_jc_javax_swing_JInternalFrame__24JDesktopIcon$vmethods;
typedef const struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$vtable	_jc_javax_swing_JInternalFrame__24JDesktopIcon$vtable;
typedef const struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$vtype	_jc_javax_swing_JInternalFrame__24JDesktopIcon$vtype;

// Class fields structure
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24swing__24JDesktopPane;
};
extern _jc_javax_swing_JInternalFrame__24JDesktopIcon$fields_struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$class_fields;

// Constructors
extern void _jc_javax_swing_JInternalFrame__24JDesktopIcon$method$_init$cd9aac833f4912ad(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *, struct _jc_javax_swing_JInternalFrame$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_accessibility_AccessibleContext$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon$method$getAccessibleContext$99df33b6e138b2ea(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_JDesktopPane$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon$method$getDesktopPane$eb64c9f6f844d088(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_JInternalFrame$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon$method$getInternalFrame$41cafd82a495e64a(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_plaf_DesktopIconUI$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon$method$getUI$503dd991769744f7(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon$method$getUIClassID$ec5a776389969db1(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JInternalFrame__24JDesktopIcon$method$setInternalFrame$5fa8b4e3c72553a7(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *, struct _jc_javax_swing_JInternalFrame$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JInternalFrame__24JDesktopIcon$method$setUI$a125c5fa92a72967(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *, struct _jc_javax_swing_plaf_DesktopIconUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JInternalFrame__24JDesktopIcon$method$updateUI$46bebc7909e18fa1(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$getAccessibleContext$99df33b6e138b2ea;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$getDesktopPane$eb64c9f6f844d088;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$getInternalFrame$41cafd82a495e64a;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$getUI$503dd991769744f7;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$getUIClassID$ec5a776389969db1;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$setInternalFrame$5fa8b4e3c72553a7;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$setUI$a125c5fa92a72967;
extern _jc_method _jc_javax_swing_JInternalFrame__24JDesktopIcon$method_info$updateUI$46bebc7909e18fa1;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_swing_JInternalFrame__24JDesktopIcon$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$vmethods {
	struct _jc_javax_accessibility_AccessibleContext$object	*(*getAccessibleContext$99df33b6e138b2ea)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;
	struct _jc_javax_swing_JDesktopPane$object	*(*getDesktopPane$eb64c9f6f844d088)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;
	struct _jc_javax_swing_JInternalFrame$object	*(*getInternalFrame$41cafd82a495e64a)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;
	struct _jc_javax_swing_plaf_DesktopIconUI$object	*(*getUI$503dd991769744f7)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getUIClassID$ec5a776389969db1)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;
	void	(*setInternalFrame$5fa8b4e3c72553a7)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *, struct _jc_javax_swing_JInternalFrame$object *) _JC_JCNI_ATTR;
	void	(*setUI$a125c5fa92a72967)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *, struct _jc_javax_swing_plaf_DesktopIconUI$object *) _JC_JCNI_ATTR;
	void	(*updateUI$46bebc7909e18fa1)(_jc_env *, struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon$vmethods	javax_swing_JInternalFrame__24JDesktopIcon;
};

// Vtype
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$vtype {
	_jc_type			type;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_refs {
	struct _jc_javax_swing_JInternalFrame$object	*frame;
};

// Reference instance fields (object)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$refs {
    _jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_refs	javax_swing_JInternalFrame__24JDesktopIcon;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JInternalFrame__24JDesktopIcon$sub_nonrefs	javax_swing_JInternalFrame__24JDesktopIcon;
};

// Object instance structure
struct _jc_javax_swing_JInternalFrame__24JDesktopIcon$object {
	_jc_javax_swing_JInternalFrame__24JDesktopIcon$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon$vtype	*vtype;
	_jc_javax_swing_JInternalFrame__24JDesktopIcon$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JInternalFrame__24JDesktopIcon$vtype _jc_javax_swing_JInternalFrame__24JDesktopIcon$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JInternalFrame__24JDesktopIcon, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JInternalFrame__24JDesktopIcon$class_object;

#endif	/* _JC_javax_swing_JInternalFrame__24JDesktopIcon_H_ */
